@@ -20,7 +20,7 @@ sub process {
         $contact = ContactType->new({
             ContactName => MLStringType->new({
                     lang    => $data->{'lang'}  || 'EN',
-                    content => $contact         || 'unknown',
+                    content => $contact         || 'unkown',
                 }),
             Timezone    => $data->{'timezone'} || 'UTC',
             type        => ContactType::ContactType::Contact_type_organization(),
@@ -32,4 +32,4 @@ sub process {
     my $incident = @{$iodef->get_Incident()}[0];
     push(@{$incident->{'Contact'}},@contacts);
 }
-1;
+1;
\ No newline at end of file
