@@ -12,9 +12,10 @@ sub process {
     return unless($data->{'guid'});
     
     my $ad = ExtensionType->new({
-        dtype   => ExtensionType::DtypeType::dtype_type_string(),
-        content => $data->{'guid'},
-        meaning => 'guid'
+        dtype       => ExtensionType::DtypeType::dtype_type_string(),
+        content     => $data->{'guid'},
+        formatid    => 'uuid',
+        meaning     => 'guid hash'
     });
     
     my $incident = @{$iodef->get_Incident()}[0];
